@@ -1,4 +1,4 @@
-# $Id: Config.pm,v 1.22 2002/07/15 07:27:16 joern Exp $
+# $Id: Config.pm,v 1.24 2002/08/18 17:34:26 joern Exp $
 
 #-----------------------------------------------------------------------
 # Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
@@ -85,7 +85,12 @@ my %CONFIG_PARAMETER = (
 	base_project_dir => {
 		label => "Default Data Base Directory",
 		type => 'dir',
-		value => "/spare/dvdrip",
+		value => "/CHANGE_ME",
+	},
+	dvdrip_files_dir => {
+		label => "Default directory for .rip project files",
+		type => 'dir',
+		value => "/CHANGE_ME",
 	},
 	cluster_master_local => {
 		label => "Start Cluster Control Daemon locally",
@@ -113,14 +118,14 @@ my %CONFIG_PARAMETER = (
 		value => 'divx4',
 		presets => [
 			"SVCD","VCD","divx4","divx5",
-			"xvid","xvidcvs","fame",
-			"af6","opendivx"
+			"xvid","xvidcvs","ffmpeg4","fame",
+			"af6"
 		],
 	},
 );
 
 my @CONFIG_ORDER = qw (
-	dvd_device base_project_dir
+	dvd_device base_project_dir dvdrip_files_dir
 	play_dvd_command play_file_command play_stdin_command
 	default_video_codec show_tooltips
 	main_window_width main_window_height
@@ -136,7 +141,7 @@ sub new {
 	my @presets = (
 		Video::DVDRip::Preset->new (
 			name => "nopreset",
-			title => "- No Preset -",
+			title => "- No Modifications -",
 			tc_clip1_top	=> 0,
 			tc_clip1_bottom	=> 0,
 			tc_clip1_left	=> 0,
@@ -152,42 +157,42 @@ sub new {
 		),
 		Video::DVDRip::Preset->new (
 			name => "auto_big",
-			title => "Autoadjust, Big Frame, HQ Resize",
+			title => "Autoadjust, Big Frame Size, HQ Resize",
 			tc_fast_resize  => 0,
 			auto => 1,
 			frame_size => 'big',
 		),
 		Video::DVDRip::Preset->new (
 			name => "auto_medium",
-			title => "Autoadjust, Medium Frame, HQ Resize",
+			title => "Autoadjust, Medium Frame Size, HQ Resize",
 			tc_fast_resize  => 0,
 			auto => 1,
 			frame_size => 'medium',
 		),
 		Video::DVDRip::Preset->new (
 			name => "auto_small",
-			title => "Autoadjust, Small Frame, HQ Resize",
+			title => "Autoadjust, Small Frame Size, HQ Resize",
 			tc_fast_resize  => 0,
 			auto => 1,
 			frame_size => 'small',
 		),
 		Video::DVDRip::Preset->new (
 			name => "auto_big_fast",
-			title => "Autoadjust, Big Frame, Fast Resize",
+			title => "Autoadjust, Big Frame Size, Fast Resize",
 			tc_fast_resize  => 1,
 			auto => 1,
 			frame_size => 'big',
 		),
 		Video::DVDRip::Preset->new (
 			name => "auto_medium_fast",
-			title => "Autoadjust, Medium Frame, Fast Resize",
+			title => "Autoadjust, Medium Frame Size, Fast Resize",
 			tc_fast_resize  => 1,
 			auto => 1,
 			frame_size => 'medium',
 		),
 		Video::DVDRip::Preset->new (
 			name => "auto_small_fast",
-			title => "Autoadjust, Small Frame, Fast Resize",
+			title => "Autoadjust, Small Frame Size, Fast Resize",
 			tc_fast_resize  => 1,
 			auto => 1,
 			frame_size => 'small',
@@ -394,7 +399,7 @@ sub save {
 	my $fh = FileHandle->new;
 
 	open ($fh, "> $filename") or confess "can't write $filename";
-	print $fh q{# $Id: Config.pm,v 1.22 2002/07/15 07:27:16 joern Exp $},"\n";
+	print $fh q{# $Id: Config.pm,v 1.24 2002/08/18 17:34:26 joern Exp $},"\n";
 	print $fh "# This file was generated by Video::DVDRip Version $Video::DVDRip::VERSION\n\n";
 
 	print $fh ${$data_sref};
