@@ -1,16 +1,13 @@
-# $Id: MergeAudio.pm,v 1.13 2005/12/26 13:57:47 joern Exp $
+# $Id: MergeAudio.pm,v 1.2 2002/09/15 15:31:10 joern Exp $
 
 #-----------------------------------------------------------------------
-# Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
-# All Rights Reserved. See file COPYRIGHT for details.
+# Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
 # 
 # This program is part of Video::DVDRip, which is free software; you can
 # redistribute it and/or modify it under the same terms as Perl itself.
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::Job::MergeAudio;
-use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 # That's Perl! The job classes inherit from this class,
 # which is decided at *runtime* - this way standard and
@@ -26,12 +23,10 @@ use strict;
 sub chapter			{ shift->{chapter}			}
 sub vob_nr			{ shift->{vob_nr}			}
 sub avi_nr			{ shift->{avi_nr}			}
-sub subtitle_test		{ shift->{subtitle_test}		}
 
 sub set_chapter			{ shift->{chapter}		= $_[1]	}
 sub set_vob_nr			{ shift->{vob_nr}		= $_[1]	}
 sub set_avi_nr			{ shift->{avi_nr}		= $_[1]	}
-sub set_subtitle_test		{ shift->{subtitle_test}	= $_[1]	}
 
 sub type {
 	return "merge audio";
@@ -40,14 +35,12 @@ sub type {
 sub info {
 	my $self = shift;
 
-	my $info    = __"Merging audio";
-	$info .= " - ".__x("title #{title}", title => $self->title->nr);
-
+	my $info    = "Merging audio - title #".$self->title->nr;
 	my $nr      = $self->vob_nr;
 	my $chapter = $self->chapter;
 	
-	$info .= ", ".__x("audio track #{nr}", nr => $nr);
-	$info .= ", ".__x("chapter {chapter}", chapter => $chapter) if $chapter;
+	$info .= ", audio track #$nr";
+	$info .= ", chapter $chapter" if $chapter;
 	
 	return $info;
 }
@@ -60,54 +53,24 @@ sub init {
 		
 	$self->set_progress_show_fps ( 1 );
 
-	$self->set_progress_max (
-		$title->get_transcode_frame_cnt ( chapter => $chapter )
-	);
+	$self->set_progress_max ( $title->frames );
 
 	1;
 }
 
-sub get_diskspace_needed {
-	my $self = shift; $self->trace_in;
-
-	my $video_size = $self->title->tc_target_size * 1024;
-
-	return $video_size if $self->vob_nr == -1;
-	
-	my $bitrate = $self->title->audio_tracks
-				  ->[$self->vob_nr]
-				  ->tc_bitrate;
-
-	my $runtime = $self->title->runtime;
-
-	my $audio_size = int($runtime * $bitrate / 8);
-
-	return $audio_size + $video_size;
-}
-
-sub get_diskspace_freed {
-	my $self = shift; $self->trace_in;
-
-	my $video_size = $self->title->tc_target_size * 1024;
-
-	return $video_size;
-}
-
 sub command {
 	my $self = shift;
 
 	my $title = $self->title;
 
-	$title->set_actual_chapter ( $self->chapter );
-	$title->set_subtitle_test  ( $self->subtitle_test );
-	
+	$title->set_actual_chapter ($self->chapter);
+
 	my $command = $title->get_merge_audio_command (
-		vob_nr        => $self->vob_nr,
-		target_nr     => $self->avi_nr,
+		vob_nr    => $self->vob_nr,
+		target_nr => $self->avi_nr,
 	);
 
 	$title->set_actual_chapter (undef);
-	$title->set_subtitle_test  (undef);
 
 	return $command;
 }
@@ -117,10 +80,6 @@ sub parse_output {
 	my ($line) = @_;
 
 	if ( $line =~ /\(\d+-(\d+)\)/ ) {
-		# avimerge
-		$self->set_progress_cnt ($1);
-	} elsif ( $line =~ /(\d+)/ ) {
-		# ogmmerge
 		$self->set_progress_cnt ($1);
 	}
 
