@@ -1,16 +1,13 @@
-# $Id: TranscodeAudio.pm,v 1.9 2005/12/26 13:57:47 joern Exp $
+# $Id: TranscodeAudio.pm,v 1.1 2002/09/01 13:57:52 joern Exp $
 
 #-----------------------------------------------------------------------
-# Copyright (C) 2001-2003 Jrn Reder <joern AT zyn.de>.
-# All Rights Reserved. See file COPYRIGHT for details.
+# Copyright (C) 2001-2002 Jrn Reder <joern@zyn.de> All Rights Reserved
 # 
 # This program is part of Video::DVDRip, which is free software; you can
 # redistribute it and/or modify it under the same terms as Perl itself.
 #-----------------------------------------------------------------------
 
 package Video::DVDRip::Job::TranscodeAudio;
-use Locale::TextDomain qw (video.dvdrip);
-use Video::DVDRip::FixLocaleTextDomainUTF8;
 
 use base Video::DVDRip::Job::TranscodeVideo;
 
@@ -18,9 +15,9 @@ use Carp;
 use strict;
 
 sub vob_nr			{ shift->{vob_nr}			}
-sub avi_nr			{ shift->{avi_nr}			}
-
 sub set_vob_nr			{ shift->{vob_nr}		= $_[1]	}
+
+sub avi_nr			{ shift->{avi_nr}			}
 sub set_avi_nr			{ shift->{avi_nr}		= $_[1]	}
 
 sub type {
@@ -28,38 +25,20 @@ sub type {
 }
 
 sub info {
-	my $self = shift; $self->trace_in;
-
-	my $info = __("Transcoding audio");
-	$info .= " - ".__x("title #{title}", title => $self->title->nr);
+	my $self = shift;
 
+	my $info = "Transcoding audio - title #".$self->title->nr;
 	my $nr      = $self->vob_nr;
 	my $chapter = $self->chapter;
 	
-	$info .= ", ".__x("track #{nr}", nr => $nr);
-	$info .= ", ".__x("chapter #{chapter}", chapter => $chapter) if $chapter;
+	$info .= ", track #$nr";
+	$info .= ", chapter #$chapter" if $chapter;
 	
 	return $info;
 }
 
-sub get_diskspace_needed {
-	my $self = shift; $self->trace_in;
-
-	my $bitrate = $self->title->audio_tracks
-				  ->[$self->vob_nr]
-				  ->tc_bitrate;
-
-	my $runtime = $self->title->runtime;
-	
-	return int($runtime * $bitrate / 8);
-}
-
-sub get_diskspace_freed {
-	return 0;
-}
-
 sub command {
-	my $self = shift; $self->trace_in;
+	my $self = shift;
 
 	my $title = $self->title;
 
@@ -75,19 +54,4 @@ sub command {
 	return $command;
 }
 
-sub commit {
-	my $self = shift;
-
-	if ( $self->bc ) {
-		$self->bc->add_audio_size (
-			bytes => -s $self->bc->title->target_avi_audio_file (
-				vob_nr => $self->vob_nr,
-				avi_nr => $self->avi_nr,
-			)
-		);
-	}
-	
-	1;
-}
-
 1;
